import * as types from './actionTypes';
import UserApi from '../api/mockUserApi';
import {beginAjaxCall, ajaxCallError} from './ajaxStatusActions';
import fetch from 'isomorphic-fetch';

export function loadUsersSuccess(users) {
  return {
    type: types.LOAD_USERS_SUCCESS, users
  };
}

export function createUserSuccess(user) {
  return {
    type: types.CREATE_USER_SUCCESS, user
  };
}

export function updateUserSuccess(user) {
  return {
    type: types.UPDATE_USER_SUCCESS, user
  };
}

export function deleteUserSuccess(userId){
  return {type: types.DELETE_USER_SUCCESS, userId};
}

// thunks:

export function loadUsers(keyword) {
  return function(dispatch) {
    dispatch(beginAjaxCall());

    return UserApi.getAllUsers(keyword).then(users => {
      dispatch(loadUsersSuccess(users));
    }).catch(error => {
      throw(error);
    });
  };
}

export function saveUser(user) {
  return function (dispatch, getState) {
    dispatch(beginAjaxCall());

    return UserApi.saveUser(user).then(savedUser => {
      user.id ? dispatch(updateUserSuccess(savedUser)) :
        dispatch(createUserSuccess(savedUser));
    }).catch(error => {
      dispatch(ajaxCallError(error));
      throw(error);
    });
  };
}


export function deleteUser(userId){
  return function(dispatch, getState){
    dispatch(beginAjaxCall());
    
    return UserApi.deleteUser(userId).then(() => {
      dispatch(deleteUserSuccess(userId));
    }).catch(error => {
      dispatch(ajaxCallError(error));
      throw(error);
    });
  };
}