import * as types from './actionTypes';
import {beginAjaxCall, ajaxCallError} from './ajaxStatusActions';
import fetch from 'isomorphic-fetch';
import {ApiPath} from '../routes';

export function loadUsersSuccess(users) {
  return {
    type: types.LOAD_USERS_SUCCESS, users
  };
}

export function createUserSuccess(user) {
  return {
    type: types.CREATE_USER_SUCCESS, user
  };
}

export function updateUserSuccess(user) {
  return {
    type: types.UPDATE_USER_SUCCESS, user
  };
}

export function deleteUserSuccess(userId){
  return {type: types.DELETE_USER_SUCCESS, userId};
}

// thunks:

export function loadUsers(keyword) {
  return function(dispatch) {
    dispatch(beginAjaxCall());
    let path = `${ApiPath.API}/api/user?`;

    path += `$filter=IsDeleted eq false`;
    if(keyword){
      //add filters
      path += ` and substringof('${keyword}', UserName) eq true`;
    }

    return fetch(path)
      .then(response => response.json())
      .then(users =>{
        dispatch(loadUsersSuccess(users));
      })
      .catch(error => {
        dispatch(ajaxCallError(error));
        throw(error);
      });
  };
}

export function saveUser(user) {
  return function (dispatch, getState) {
    dispatch(beginAjaxCall());

    const savePath = ApiPath.API + (user.id? '/api/user/update' : '/api/user');

    return fetch(savePath, {
        method: 'post',
        headers: {
          'Accept': 'application/json',
          'Content-Type': 'application/json'
        },
        body: JSON.stringify(user)
      })
      .then(response => response.json())
      .then(savedUser => {
        user.id? dispatch(updateUserSuccess(savedUser)) : dispatch(createUserSuccess(savedUser));
      })
      .catch(error => {
        dispatch(ajaxCallError(error));
        throw(error);
      });
  };
}


export function deleteUser(userId){
  return function(dispatch, getState){
    dispatch(beginAjaxCall());

    return fetch(`${ApiPath.API}/api/user/delete/${userId}`, {
        method: 'get',
        headers: {
          'Accept': 'application/json',
          'Content-Type': 'application/json'
        }
      })
      .then(response => response.json())
      .then(() => {
        dispatch(deleteUserSuccess(userId));
      })
      .catch(error => {
        dispatch(ajaxCallError(error));
        throw(error);
      });
  };
}
