import delay from './delay';

// This file mocks a web API by working with the hard-coded data below.
// It uses setTimeout to simulate the delay of an AJAX call.
// All calls return promises.
const categories = [
  {
    id: 1,
    name: 'BT - 50 Front Bumper',
    category: 'Body and main'
  },
  {
    id: 2,
    name: 'CX5 Fog Light',
    category: 'Lighting and Signaling'
  }
];

//This would be performed on the server in a real app. Just stubbing in.
const generateId = () => {
  return categories.length + 1;
};

class CategoryApi {
  static getAllCategories() {
    return new Promise((resolve, reject) => {
      setTimeout(() => {
        resolve(Object.assign([], categories));
      }, delay);
    });
  }

  static saveCategory(category) {
    return new Promise((resolve, reject) => {
      setTimeout(() => {
        // Simulate server-side validation

        if (category.id) {
          const existingCategoryIndex = categories.findIndex(a => a.id == category.id);
          categories.splice(existingCategoryIndex, 1, category);
        } else {
          //Just simulating creation here.
          //The server would generate ids for new users in a real app.
          //Cloning so copy returned is passed by value rather than by reference.
          category.id = generateId();
          categories.push(category);
        }
        resolve(Object.assign({}, category));
      }, delay);
    });
  }

  static deleteCategory(categoryId) {
    return new Promise((resolve, reject) => {
      setTimeout(() => {
        const indexOfCategoryToDelete = categories.findIndex(category => {
          category.categoryId == categoryId;
        });
        categories.splice(indexOfCategoryToDelete, 1);
        resolve();
      }, delay);
    });
  }
}

export default CategoryApi;
