import delay from './delay';

// This file mocks a web API by working with the hard-coded data below.
// It uses setTimeout to simulate the delay of an AJAX call.
// All calls return promises.
const roles = [{id: "4f0d7656-e25e-4730-8f43-4b6021c4359b",name: "Admin"},{id: "0e875492-4680-4d64-81a2-dc8ef08edb01",name: "Dealer"},{id: "06267821-e1ad-4c3f-b763-c0f106e475d5",name: "User"}];

function replaceAll(str, find, replace) {
  return str.replace(new RegExp(find, 'g'), replace);
}

//This would be performed on the server in a real app. Just stubbing in.
const generateId = (role) => {
  return replaceAll(role.title, ' ', '-');
};

class roleApi {
  static getAllRoles() {
    return new Promise((resolve, reject) => {
      setTimeout(() => {
        resolve(Object.assign([], roles));
      }, delay);
    });
  }

  static saveRole(role) {
    role = Object.assign({}, role); // to avoid manipulating object passed in.
    return new Promise((resolve, reject) => {
      setTimeout(() => {
        // Simulate server-side validation
        const minRoleTitleLength = 1;
        if (role.title.length < minRoleTitleLength) {
          reject(`Title must be at least ${minRoleTitleLength} characters.`);
        }

        if (role.id) {
          const existingRoleIndex = roles.findIndex(a => a.id == role.id);
          roles.splice(existingRoleIndex, 1, role);
        } else {
          //Just simulating creation here.
          //The server would generate ids and watchHref's for new roles in a real app.
          //Cloning so copy returned is passed by value rather than by reference.
          role.id = generateId(role);
          role.watchHref = `http://www.pluralsight.com/roles/${role.id}`;
          roles.push(role);
        }

        resolve(role);
      }, delay);
    });
  }

  static deleteRole(roleId) {
    return new Promise((resolve, reject) => {
      setTimeout(() => {
        const indexOfRoleToDelete = roles.findIndex(role => {
          role.roleId == roleId;
        });
        roles.splice(indexOfRoleToDelete, 1);
        resolve();
      }, delay);
    });
  }
}

export default roleApi;
