import delay from './delay';

// This file mocks a web API by working with the hard-coded data below.
// It uses setTimeout to simulate the delay of an AJAX call.
// All calls return promises.
const users = [
  {
    id: 1,
    username: 'GBallesteros',
    firstName: 'Gerald',
    lastName: 'Ballesteros',
    email: 'gballesteros@blastasia.com',
    roleId: 1
  },
  {
    id: 2,
    username: 'JDelacruz',
    firstName: 'Joseph',
    lastName: 'Dela Cruz',
    email: 'jdelacruz@blastasia.com',
    roleId: 2
  },
  {
    id: 3,
    username: 'APerez',
    firstName: 'Angelo',
    lastName: 'Perez',
    email: 'aperez@blastasia.com',
    roleId: 3,
    dealerId: 2
  },
  {
    id: 4,
    username: 'CRodolfo',
    firstName: 'Carl',
    lastName: 'Rodolfo',
    email: 'crodolfo@blastasia.com',
    roleId: 3,
    dealerId: 3
  }
];

//This would be performed on the server in a real app. Just stubbing in.
const generateId = () => {
  return users.length + 1;
};

class UserApi {
  static getAllUsers(keyword) {
    return new Promise((resolve, reject) => {
      setTimeout(() => {
        resolve(Object.assign([], (keyword? 
          users.filter(function(user){
            return (user.username.toLowerCase().indexOf(keyword.toLowerCase()) !== -1);
          }):
          users)));

        // resolve(Object.assign([], users));
      }, delay);
    });
  }

  static saveUser(user) {
    return new Promise((resolve, reject) => {
      setTimeout(() => {
        // Simulate server-side validation
        const minUserNameLength = 3;
        if (user.firstName.length < minUserNameLength) {
          reject(`First Name must be at least ${minUserNameLength} characters.`);
        }

        if (user.lastName.length < minUserNameLength) {
          reject(`Last Name must be at least ${minUserNameLength} characters.`);
        }

        if (user.id) {
          const existingUserIndex = users.findIndex(a => a.id == user.id);
          users.splice(existingUserIndex, 1, user);
        } else {
          //Just simulating creation here.
          //The server would generate ids for new users in a real app.
          //Cloning so copy returned is passed by value rather than by reference.
          user.id = generateId();
          users.push(user);
        }

        resolve(Object.assign({}, user));
      }, delay);
    });
  }

  static deleteUser(userId) {
    return new Promise((resolve, reject) => {
      setTimeout(() => {
        const indexOfUserToDelete = users.findIndex(user => {
          user.userId == userId;
        });
        users.splice(indexOfUserToDelete, 1);
        resolve();
      }, delay);
    });
  }
}

export default UserApi;
