import React, {PropTypes} from 'react';
import Header from './common/Header';
import Footer from './common/Footer';
import {connect} from 'react-redux';
import {isAuthenticated, getUser, removeCredentials} from '../store/authStore.js';

class App extends React.Component {
  constructor(props, context) {
    super(props, context);

    if(!isAuthenticated())
      this.context.router.push(`/login`);


    this.logOut = this.logOut.bind(this);
  }

  logOut(event){
    event.preventDefault();
    removeCredentials();
    this.context.router.push(`/login`);
  }

  render() {
    return (
      <div>
        {isAuthenticated() && 
          (<Header
            loading={this.props.loading}
            user={getUser()}
            logOut={this.logOut}
          />)}

        {this.props.children}
        <Footer/>
      </div>
    );
  }
}

App.propTypes = {
  children: PropTypes.object.isRequired,
  loading: PropTypes.bool.isRequired
};


App.contextTypes = {
  router: PropTypes.object
};

function mapStateToProps(state, ownProps) {
  return {
    loading: state.ajaxCallsInProgress > 0
  };
}
export default connect(mapStateToProps)(App);
