import React, { PropTypes } from 'react';
import { connect } from 'react-redux';
import { bindActionCreators } from 'redux';
import bootstrap from 'bootstrap';
import toastr from 'toastr';
import * as categoryActions from '../../actions/categoryActions';
import CategoryModal from './Modal/CategoryModal';
import CategoryList from './CategoryList.js';

class CategoriesPage extends React.Component {
  constructor(props, context) {
    super(props,context);
    this.onSearch = this.onSearch.bind(this);
    this.onSelect = this.onSelect.bind(this);
    this.state = {
      selectedCategory: Object.assign({}, props.selectedCategory)
    };
  }

  componentWillReceiveProps(nextProps){
    if(this.props.selectedCategory.id != nextProps.selectedCategory.id){
			this.setState({selectedCategory: Object.assign({}, nextProps.selectedCategory)});
		}
  }

  onSearch(event){

  }

  onSelect(event){
    let categoryId = event.target.name;
    const {categories} = this.props;
    let category = categories.filter(category => category.id == categoryId);
    this.setState({selectedCategory: category[0]});
  }

  render() {
    const {categories} = this.props;
    return (
        <div className="container">
        <h1>Manage Categories</h1>
          <div className="row">
            <div className="col-md-2">
                <input onKeyPress={this.onSearch} name="listSearch" placeholder="Search" type="text" className="input-sm form-control" />
            </div>
            <div className="col-md-10">
              <button type="button" className="btn btn-primary pull-right" data-toggle="modal" data-target="#addCategory">Add</button>
              <CategoryModal modalTitle="Add Category" modalId="addCategory"/>
              <CategoryModal modalTitle="Edit Category" modalId="editCategory" category={this.state.selectedCategory}/>
            </div>
          </div>
          <CategoryList categories={categories} onSelect={this.onSelect}/>
        </div>
    );
  }
}

CategoriesPage.propTypes = {
  selectedCategory: PropTypes.object,
  categories: PropTypes.array.isRequired,
  actions: PropTypes.object.isRequired
};


function mapStateToProps(state) {
  let category = {id: '', name: '', category:''};
  return {
    categories: state.categories,
    selectedCategory: category
  };
}

function mapDispatchToProps(dispatch) {
  return {
    actions: bindActionCreators(categoryActions, dispatch)
  };
}

export default connect(mapStateToProps, mapDispatchToProps)(CategoriesPage);
