import React, {PropTypes}  from 'react';
import bootstrap from 'bootstrap';
import CategoryForm from '../CategoryForm';
import * as categoryActions from '../../../actions/categoryActions';
import {connect} from 'react-redux';
import {bindActionCreators} from 'redux';
import toastr from 'toastr';

class CategoryModal extends React.Component {
	constructor(props, context) {
		super(props,context);
		this.state = {
			category: Object.assign({}, this.props.category),
			errors: {}
		};
		this.updateCategoryState = this.updateCategoryState.bind(this);
		this.saveCategory = this.saveCategory.bind(this);
	}

	componentWillReceiveProps(nextProps) {
		if (this.props.category.id != nextProps.category.id){
			this.setState({category: Object.assign({}, nextProps.category)});
		}
	}

	updateCategoryState(event) {
		const field = event.target.name;
		let category = this.state.category;
		category[field] = event.target.value;
		return this.setState({category: category});
	}

	categoryFormIsValid(){
		let formIsValid = true;
		let errors = {};

		if (this.state.category.name.length <5) {
			errors.title = 'Category must be at least 5 characters';
		}

		this.setState({errors: errors});
		return formIsValid;
	}

	saveCategory(event){
		event.preventDefault();

		if (!this.categoryFormIsValid()) {
			return;
		}

		this.props.actions.saveCategory(this.state.category)
			.then(() => this.redirect())
			.catch(error => {
				toastr.error(error);
			});

	}
	redirect() {
		toastr.success('Category saved');
		let newCategory = {id: '' , name:'', category:''};
		this.setState({category: newCategory});
	}

  render() {
    return (
			<div className="modal fade" id={this.props.modalId} tabIndex="-1" role="dialog" aria-labelledby="myModalLabel">
				<div className="modal-dialog" role="document">
					<div className="modal-content">
						<div className="modal-header">
							<h2 className="modal-title">{this.props.modalTitle}</h2>
						</div>
						<div className="modal-body">
									<CategoryForm
										category={this.state.category}
										onChange={this.updateCategoryState}/>
						</div>
						<div className="modal-footer">
							<input type="submit" value="Save" className="btn btn-primary" onClick={this.saveCategory}/>
							<input type="button" className="btn btn-default" value="Cancel" data-dismiss="modal"/>
						</div>
					</div>
				</div>
			</div>
    );
  }
}

CategoryModal.propTypes = {
	actions: PropTypes.object.isRequired,
	category: PropTypes.object.isRequired,
    modalId: PropTypes.string.isRequired,
    modalTitle: PropTypes.string.isRequired
};

CategoryModal.contextTypes = {
	router: PropTypes.object
};

function getCategoryById(categories, id){
	const category = categories.filter(category => category.id == id);
	if (category) return categories[0];
	return null;
}

function mapStateToProps(state, ownProps){
	let category = {id: '', name:'', category: ''};
		if(ownProps.category){
			category = ownProps.category;
		}

	return {
		category:category
	};
}

function mapDispatchToProps(dispatch){
	return {
		actions: bindActionCreators(categoryActions, dispatch)
	};
}

export default connect(mapStateToProps, mapDispatchToProps)(CategoryModal);
