import React, {PropTypes} from 'react';
import GenericRowGenerator from './GenericRowGenerator';

class GenericList extends React.Component {
    constructor(props, context) {
        super(props, context);
        
        this.styleMap = {
            list: {
                width: "100%",
                border: "1px solid silver",
                overflowY: "auto",
                marginTop: "2px",
                borderRadius: "4px"
            },
            table: {
                marginBottom: "0px"
            },
            panel: {
                marginBottom: "7px"
            }
        };
        
        this.ellipsisConfig = {
            ellipsis: '...',
            height: 20,
            watch: true
        };
        
        this.onSearch = this.onSearch.bind(this);
    }
    
    componentDidUpdate() {
        this.jqueryInitialize();
    }
    
    componentDidmount() {
        this.jqueryInitialize();
    }
    
    onSearch(event) {
        if(event.key === 'Enter'){
            this.props.onSearch(event);
        }
    }
    
    jqueryInitialize() {
        let adjustListSize = () => {
            let {heightDeduction} = this.props;
            let finalDeduction = heightDeduction? heightDeduction:0;
            let container = $("#"+this.props.id);
            let footer = $("footer");                
            
            let offsetTop = container.offset().top;
            let footerSize = footer.height() + parseInt(footer.css('padding-top')) * 2;
            container.height(window.innerHeight - offsetTop - footerSize - finalDeduction);
        };
        
        $(document).ready(() => {
            $('.genericItem').dotdotdot(this.ellipsisConfig);
            $(window).on('resize', () => {
                adjustListSize();
            });
            adjustListSize();
        });
    }
    
    render(){
        setTimeout(() => {
            this.jqueryInitialize();  
        });
        const props = this.props;
        const {selectedItem} = this.props;
        const {itemKeyExtractor} = this.props;
        return (
            <div style={this.styleMap.panel} className="panel panel-default">
                <div className="panel-heading">
                    <b>{props.label}</b>
                </div>
                <input onKeyPress={this.onSearch} name="listSearch" placeholder="Search" type="text" className="input-sm form-control" />
                <div id={props.id} style={this.styleMap.list}>
                    <table className="table" style={this.styleMap.table}>
                        <tbody>
                            {props.items.map(item => 
                                <GenericRowGenerator
                                    key={itemKeyExtractor(item)}
                                    item={item}
                                    itemDisplayGenerator={props.itemDisplayGenerator}
                                    itemKeyExtractor={itemKeyExtractor}
                                    onSelect={props.onSelect}
                                    selected={selectedItem && itemKeyExtractor(selectedItem) == itemKeyExtractor(item)}/>)}
                        </tbody>
                    </table>
                </div>
            </div>
        );
    }
}

GenericList.propTypes = {
    id: PropTypes.string.isRequired,
    label: PropTypes.string.isRequired,
    heightDeduction: PropTypes.string,
    onSelect: PropTypes.func.isRequired,
    onSearch: PropTypes.func.isRequired,
    selectedItem: PropTypes.object,
    items: PropTypes.array.isRequired,
    itemKeyExtractor: PropTypes.func.isRequired,
    itemDisplayGenerator: PropTypes.func.isRequired
};

export default GenericList;
