import React, {PropTypes} from 'react';
import {connect} from 'react-redux';
import {bindActionCreators} from 'redux';
import * as loginActions from '../../actions/loginActions';
import toastr from 'toastr';

export class LogInPage extends React.Component {
  constructor(props, context) {
    super(props, context);
    this.state = {
      user: {},
      loading: false
    };

    this.updateUserState = this.updateUserState.bind(this);
    this.login = this.login.bind(this);
  }


  updateUserState(event) {
    const field = event.target.name;
    let user = this.state.user;
    user[field] = event.target.value;
    return this.setState({user: user});
  }

  login(event){
    event.preventDefault();

    const {username, password} = this.state.user;

    this.setState({loading: true});
    this.props.actions.login(username, password)
      .then(() => this.redirect())
      .catch(error => {
        toastr.error(error);
        this.setState({loading: false, user: {}});
      });
  }

  redirect() {
    this.setState({saving: false, user: {}});
    this.context.router.push(`/`);
  }

  render() {
    return (
      <div className="text-center">
        <div className="mazdaLoginForm">
          <img 
            src={"http://www.diablomotor.com/wp-content/uploads/2010/11/logo-mazda-1997.jpg"}
            className="mazdaLogo img-rounded" />
          <form>
            <div className="form-group">
              <input
                name="username"
                type="text"
                placeholder="Username"
                className="form-control"
                onChange={this.updateUserState} />
              <input
                name="password"
                type="password"
                placeholder="Password"
                className="form-control"
                onChange={this.updateUserState} />
              <button
                type="submit"
                className="btn btn-default btn-block"
                disabled={this.state.loading}
                onClick={this.login}> Sign In </button>
            </div>
          </form>

          <div className="mazdaLoginNote text-center">
          Having problems? Please contact system administrator or email us at test@test.com
          </div>
        </div>
      </div>
    );
  }
}

LogInPage.propTypes = {
  // user: PropTypes.object,
  // users: PropTypes.array.isRequired,
  actions: PropTypes.object.isRequired
};

LogInPage.contextTypes = {
  router: PropTypes.object
};

function mapStateToProps(state, ownProps) {
  return {
    // users: users
  };
}

function mapDispatchToProps(dispatch) {
  return {
    actions: bindActionCreators(loginActions, dispatch)
  };
}

export default connect(mapStateToProps, mapDispatchToProps)(LogInPage);
