import React, {PropTypes}  from 'react';
import bootstrap from 'bootstrap';
import ProductForm from '../ProductForm';
import * as productActions from '../../../actions/productActions';
import {connect} from 'react-redux';
import {bindActionCreators} from 'redux';
import toastr from 'toastr';

class ProductModal extends React.Component {
	constructor(props, context) {
		super(props,context);
		this.state = {
			product: Object.assign({}, this.props.product),
			errors: {}
		};
		this.updateProductState = this.updateProductState.bind(this);
		this.saveProduct = this.saveProduct.bind(this);
	}

	componentWillReceiveProps(nextProps) {
		if(this.props.product.id != nextProps.product.id){
			this.setState({product: Object.assign({}, nextProps.product)});
		}
	}

	updateProductState(event) {
		const field = event.target.name;
		let product = this.state.product;
		product[field] = event.target.value;
		return this.setState({product: product});
	}

	productFormIsValid(){
		let formIsValid = true;
		let errors = {};

		if (this.state.product.name.length <5) {
			errors.title = 'Product must be at least 5 characters';
		}

		this.setState({errors: errors});
		return formIsValid;
	}

	saveProduct(event) {
		event.preventDefault();

		if(!this.productFormIsValid()) {
			return;
		}

		this.props.actions.saveProduct(this.state.product)
			.then(() => this.redirect())
			.catch(error => {
				toastr.error(error);
			});
	}

	redirect() {
		toastr.success('Product saved');
		let newProduct = {id: '' , name:'', category:'', dealerPrice:'', srp:'',  description:''};
		this.setState({product: newProduct});
		//this.setState({product: {}});
	}

	render(){
		return (
			<div className="modal fade" id={this.props.modalId} tabIndex="-1" role="dialog" aria-labelledby="myModalLabel">
				<div className="modal-dialog" role="document">
					<div className="modal-content">
						<div className="modal-header">
							<h2 className="modal-title">{this.props.modalTitle}</h2>
						</div>
						<div className="modal-body">
								<ProductForm
								product={this.state.product}
								onChange={this.updateProductState}/>
						</div>
						<div className="modal-footer">
							<input type="submit" value="Save" className="btn btn-primary" onClick={this.saveProduct}/>
							<input type="button" className="btn btn-default" value="Cancel" data-dismiss="modal"/>
						</div>
					</div>
				</div>
			</div>
		);
	}
}

ProductModal.propTypes = {
	actions: PropTypes.object.isRequired,
	product: PropTypes.object.isRequired,
    modalId: PropTypes.string.isRequired,
    modalTitle: PropTypes.string.isRequired
};

ProductModal.contextTypes = {
	router: PropTypes.object
};

function getProductId(products, id){
	const product = products.filter(product => product.id == id);
	if (product) return products[0];
	return null;
}

function mapStateToProps(state,ownProps){
	let product = {id: '' , name:'', category:'', dealerPrice:'', srp:'',  description:''};
	if(ownProps.product) {
		product = ownProps.product;
	}

	return {
		product: product
	};
}

function mapDispatchToProps(dispatch){
	return {
		actions: bindActionCreators(productActions, dispatch)
	};
}

export default connect(mapStateToProps,mapDispatchToProps)(ProductModal);
