import React, { PropTypes } from 'react';
import { connect } from 'react-redux';
import { bindActionCreators } from 'redux';
import bootstrap from 'bootstrap';
import * as productActions from '../../actions/productActions';
import ProductModal from './Modal/ProductModal';
import ProductList from './ProductList';
import toastr from 'toastr';

class ProductsPage extends React.Component {
  constructor(props, context) {
      super(props,context);
      this.onSearch = this.onSearch.bind(this);
      this.onSelect = this.onSelect.bind(this);
      this.state = {
        selectedProduct: Object.assign({}, props.selectedProduct)
      };
  }

  componentWillReceiveProps(nextProps){
    if(this.props.selectedProduct.id != nextProps.selectedProduct.id){
			this.setState({selectedProduct: Object.assign({}, nextProps.selectedProduct)});
		}
  }

  onSearch(event){

  }

  onSelect(event){
    let productId = event.target.name;
    const {products} = this.props;
    let product = products.filter(product => product.id == productId);
    this.setState({selectedProduct: product[0]});
  }

  render() {
    const {products} = this.props;
    return (
      <div className="container">
      <h1>Products</h1>
      <div className="row">
        <div className="col-md-2">
          <input onKeyPress={this.onSearch} name="listSearch" placeholder="Search" type="text" className="input-sm form-control" />
        </div>
        <div className="col-md-10">
          <button className="btn btn-primary pull-right" data-toggle="modal" data-target="#addProduct">Add</button>
            <ProductModal modalTitle="Add Product" modalId="addProduct" />
            <ProductModal modalId="editProduct" modalTitle="Edit Product" product={this.state.selectedProduct} />
          </div>
      </div>
      <ProductList products={products} onSelect={this.onSelect}/>
      </div>
    );
  }
}

ProductsPage.propTypes = {
  products: PropTypes.array.isRequired,
  actions: PropTypes.object.isRequired
};


function mapStateToProps(state, ownProps) {
  let product = {id: '' , name:'', category:'', dealerPrice:'', srp:'',  description:''};
  return {
    products: state.products,
    selectedProduct: product
  };
}

function mapDispatchToProps(dispatch) {
  return {
    actions: bindActionCreators(productActions, dispatch)
  };
}

export default connect(mapStateToProps, mapDispatchToProps)(ProductsPage);
