import React, {PropTypes} from 'react';
import {connect} from 'react-redux';
import {bindActionCreators} from 'redux';
import * as userActions from '../../actions/userActions';
import UserForm from './UserForm';
import toastr from 'toastr';
import GenericList from '../common/List/GenericList';
import {ExtractIdFromObject} from '../common/Tools/Utility';
import {rolesFormattedForDropdown} from '../../selectors/selectors';

export class ManageUserPage extends React.Component {
  constructor(props, context) {
    super(props, context);
    this.state = {
      users: Object.assign([], this.props.users),
      user: Object.assign({}, this.props.user),
      userBackup: {},
      isEditMode: false,
      errors: {},
      saving: false,
      firstLoad: true,
      isChangePassword: false,
      //TEMPORARY. GET ROLES AND DEALERS FROM API. mapStateToProps, SAME WITH users
      // allRoles: [{value: "4f0d7656-e25e-4730-8f43-4b6021c4359b",text: "Admin"},{value: "0e875492-4680-4d64-81a2-dc8ef08edb01",text: "Dealer"},{value: "06267821-e1ad-4c3f-b763-c0f106e475d5",text: "User"}],
      allDealers: [{value: 1,text: 'Concorde Car Accessories'},{value: 2,text: 'Jed Motor Parts'},{value: 3,text: 'Optimum Auto Parts and Services'}]
    };

    this.updateUserState = this.updateUserState.bind(this);
    this.saveUser = this.saveUser.bind(this);
    this.deleteUser = this.deleteUser.bind(this);
    this.onSearch = this.onSearch.bind(this);
    this.onSelect = this.onSelect.bind(this);
    this.newUser = this.newUser.bind(this);
    this.onClickChangePassword = this.onClickChangePassword.bind(this);
    this.setToEditMode = this.setToEditMode.bind(this);
    this.setToViewMode = this.setToViewMode.bind(this);
  }

  componentWillReceiveProps(nextProps) {
    if (nextProps.user) {
      if(this.state.user.id != nextProps.user.id){

        if(nextProps.user.roles)
          this.setState({user: Object.assign({}, nextProps.user, {roleId: nextProps.user.roles[0].id}, {roleName: nextProps.user.roles[0].name})});
        else
          this.setState({user: Object.assign({}, nextProps.user)});
      }
    }
    this.setState({firstLoad: Object.assign({}, nextProps.firstLoad)});
    this.setState({users: Object.assign([], nextProps.users)});
  }

  updateUserState(event) {
    const field = event.target.name;
    let user = this.state.user;
    user[field] = event.target.value;
    return this.setState({user: user});
  }

  userFormIsValid() {
    let formIsValid = true;
    let errors = {};

    const requiredFields = ['userName','firstName','lastName'];

    if(this.state.user.roleId != '0e875492-4680-4d64-81a2-dc8ef08edb01'){ //TEMPORARY. DETERMINE IF ROLE IS NOT DEALER
      requiredFields.push('email');
      if(this.state.isChangePassword || this.state.user.id == ''){
        requiredFields.push('password');
        requiredFields.push('confirmPassword');
      }
    }

    requiredFields.forEach((field) => {
      if(this.state.user[field] == '' || this.state.user[field] == undefined){
        errors[field] = 'This field is required.';
        formIsValid = false;
      }
    });



    this.setState({errors: errors});
    return formIsValid;
  }

  saveUser(event) {
    event.preventDefault();

    if (!this.userFormIsValid()) {
      return;
    }
    this.setState({saving: true});

    const pendingUser = Object.assign({}, this.state.user);

    //add property
    pendingUser.roles = [];
    pendingUser.roles[0] = {
      id: pendingUser.roleId
    };

    //remove unnecessary properties
    delete pendingUser.confirmPassword;
    delete pendingUser.roleId;
    delete pendingUser.roleName;

    this.props.actions.saveUser(pendingUser)
      .then(() => this.redirect())
      .catch(error => {
        toastr.error(error);
        this.setState({saving: false});
      });
  }

  deleteUser(event){
    event.preventDefault();

    const userId = event.target.id;

    this.props.actions.deleteUser(userId)
      .then(() => {
        toastr.success('User deleted');
        this.context.router.push('/users');
      })
      .catch(error => {
        toastr.error(error);
      });
  }

  redirect() {
    this.setState({saving: false});
    toastr.success('User saved');

    let savedUser = Object.assign([], this.state.users);
    const userName = this.state.user.userName;

    savedUser = savedUser.filter(function(u){
      return u.userName == userName;
    });

    this.context.router.push(`/user/${savedUser[0].id}`);
  }

  onClickChangePassword(event){
    this.setState({isChangePassword: !this.state.isChangePassword});
  }

  onSearch(event) {
      this.props.actions.loadUsers(event.target.value);
  }

  onSelect(event) {
      const id = event.target.attributes.name.value;
      this.setState({firstLoad: false,
        isChangePassword: false,
        errors: {},
        isEditMode: false
      });
      this.context.router.push(`/user/${id}`);
  }

  userDisplayGenerator(user){
    return user.userName;
  }

  newUser(){
      this.setState({isEditMode: true});
      this.context.router.push(`/user/`);
  }

  setToEditMode(event){
    event.preventDefault();

    const user = Object.assign({}, this.state.user);

    this.setState({isEditMode: true,
      userBackup: user
    });
  }

  setToViewMode(event){
    event.preventDefault();

    const userBackup = Object.assign({}, this.state.userBackup);

    this.setState({isEditMode: false,
      user: userBackup
    });
  }

  render() {
    return (
      <div clasName="col-md-12">
        <div className="col-sm-3">
            <GenericList
                label="Users"
                id="userList"
                items={this.state.users}
                itemKeyExtractor={ExtractIdFromObject}
                itemDisplayGenerator={this.userDisplayGenerator}
                onSelect={this.onSelect}
                onSearch={this.onSearch}
                selectedItem={this.state.user}
                heightDeduction="55"
                />
            <div>
                <button className="btn btn-sm btn-primary pull-right"
                  onClick={this.newUser}>
                  <span className="glyphicon glyphicon-plus-sign"></span>
                  &nbsp;&nbsp;Add
                  </button>
            </div>
        </div>
        <div className="col-md-9">

          {this.state.firstLoad &&
          <UserForm
            user={this.state.user}
            errors={this.state.errors}
            onChange={this.updateUserState}
            onSave={this.saveUser}
            onDelete={this.deleteUser}
            onClickChangePassword={this.onClickChangePassword}
            saving={this.state.saving}
            allDealers={this.state.allDealers}
            allRoles={this.props.roles}
            isChangePassword={this.state.isChangePassword}
            isEditMode={this.state.isEditMode}
            setToEditMode={this.setToEditMode}
            setToViewMode={this.setToViewMode}
            />
          }
        </div>
      </div>
    );
  }
}

ManageUserPage.propTypes = {
  user: PropTypes.object,
  users: PropTypes.array.isRequired,
  roles: PropTypes.array.isRequired,
  actions: PropTypes.object.isRequired
};

ManageUserPage.contextTypes = {
  router: PropTypes.object
};

function getUserById(users, id) {
  const user = users.filter(user => user.id == id);
  if (user) return user[0];
  return null;
}

function mapStateToProps(state, ownProps) {
  const userId = ownProps.params.id;

  let user = {id: '',userName:'',firstName: '',lastName: '',email: '',roleId:'06267821-e1ad-4c3f-b763-c0f106e475d5', roleName:'', password: ''};


  if (userId && state.users.length > 0) {
    user = getUserById(state.users, userId);
  }

  return {
    user: user,
    users: state.users,
    firstLoad: state.firstLoad,
    roles: rolesFormattedForDropdown(state.roles)
  };
}

function mapDispatchToProps(dispatch) {
  return {
    actions: bindActionCreators(userActions, dispatch)
  };
}

export default connect(mapStateToProps, mapDispatchToProps)(ManageUserPage);
