import React from 'react';
import TextInput from '../common/TextInput';
import SelectInput from '../common/SelectInput';

const UserForm = ({user, allRoles, allDealers, onSave, onChange, onDelete, onClickChangePassword, isChangePassword, isEditMode, setToEditMode, setToViewMode, saving, errors}) => {

  const isNew = (user.id == '' || !user.id);
  const isDealer = (user.roleId == '0e875492-4680-4d64-81a2-dc8ef08edb01'); //TEMPORARY

  if(isNew)
    isEditMode = true;


  const textInputUsername =
          (<TextInput
            name="userName"
            label="Username"
            value={user.userName}
            onChange={onChange}
            error={errors.userName}
            disabled={!isEditMode}/>);

  const textInputDealer =
          (<div>
            <SelectInput
              name="dealerId"
              label="Dealer"
              value={user.dealerId}
              options={allDealers}
              onChange={onChange}
              error={errors.dealerId}
              disabled={!isEditMode}/>
              <span className="label label-info"><em>*An auto-generated password will be emailed to the dealer's email account.*</em></span>
          </div>);

  const textInputPassword =
            (<div>
              <TextInput
                name="password"
                label="Password"
                inputType="password"
                value={user.password}
                onChange={onChange}
                error={errors.password}
                disabled={(!isChangePassword && !isNew) || !isEditMode}/>
              <TextInput
                name="confirmPassword"
                label="Confirm Password"
                inputType="password"
                value={user.confirmPassword}
                onChange={onChange}
                error={errors.confirmPassword}
                disabled={(!isChangePassword && !isNew) || !isEditMode}/>
            </div>);

  const textInputEmail =
          (<TextInput
            name="email"
            inputType="email"
            label="Email Address"
            value={user.email}
            onChange={onChange}
            error={errors.email}
            disabled={!isEditMode}/>);

  const buttonGenerate =
          (<input
            type="button"
            value="Generate New Password"
            className="btn btn-primary"/>);

  const panelChangePassword =
          (<div className="well">
            <div className="text-center">
              <input
              type="button"
              value={isChangePassword? "Cancel Change Password": "Change Password"}
              className="btn btn-primary"
              onClick={onClickChangePassword}/>
            </div><br/>
            {textInputPassword}
          </div>);

  return (
    <form>
      <h1>{(isNew)? 'New User': user.userName}</h1>

      <div className="col-md-12">
        <div className="col-md-6">
          {isNew && textInputUsername}
          <TextInput
            name="firstName"
            label="First Name"
            value={user.firstName}
            onChange={onChange}
            error={errors.firstName}
            disabled={!isEditMode}/>
          <TextInput
            name="lastName"
            label="Last Name"
            value={user.lastName}
            onChange={onChange}
            error={errors.lastName}
            disabled={!isEditMode}/>
          {!isDealer && textInputEmail}
          {(isDealer && !isNew) && buttonGenerate}
        </div>
        <div className="col-md-6">
          <SelectInput
            name="roleId"
            label="Role"
            value={user.roleId}
            options={allRoles}
            onChange={onChange}
            error={errors.roleId}
            disabled={!isEditMode}/>
          {(isDealer)?
            textInputDealer :
            (isNew)? textInputPassword: isEditMode && panelChangePassword}
        </div>
      </div>

      {
        isEditMode?
        (<div className="pull-right">
          <button
            type="submit"
            disabled={saving}
            className="btn btn-primary"
            onClick={onSave}
            id="3">
            <span className="glyphicon glyphicon-ok-sign"></span>
            &nbsp;
            {saving ? 'Saving...' : 'Save'}
          </button>
          &nbsp;
          {!isNew && (<button
            disabled={saving}
            className="btn btn-primary"
            onClick={setToViewMode}>
            <span className="glyphicon glyphicon-remove-sign"></span>
            &nbsp;Cancel
          </button>)}

        </div>):
        (<div className="pull-right">
          <button
            disabled={saving}
            className="btn btn-primary"
            onClick={setToEditMode}>
            <span className="glyphicon glyphicon-edit"></span>
            &nbsp;
            Edit
          </button>
          &nbsp;
          <button
            className="btn btn-primary"
            onClick={onDelete}
            id={user.id}>
            <span className="glyphicon glyphicon-minus-sign"></span>
            &nbsp; Delete
          </button>
        </div>)
      }




    </form>
  );
};

UserForm.propTypes = {
  user: React.PropTypes.object.isRequired,
  onSave: React.PropTypes.func.isRequired,
  onChange: React.PropTypes.func.isRequired,
  onDelete: React.PropTypes.func.isRequired,
  onClickChangePassword: React.PropTypes.func.isRequired,
  allRoles: React.PropTypes.array.isRequired,
  allDealers: React.PropTypes.array.isRequired,
  isChangePassword: React.PropTypes.bool,
  isEditMode: React.PropTypes.bool,
  setToEditMode: React.PropTypes.func,
  setToViewMode: React.PropTypes.func,
  saving: React.PropTypes.bool,
  errors: React.PropTypes.object
};


export default UserForm;
